import { ChangeEvent } from 'react';
import { Rules, StrictRules } from './validators';
export type Value = number | string | boolean | Date | null | undefined;
type FormControlType = 'text' | 'number';
interface FormControlSetup {
    label?: string;
    type?: FormControlType;
    defaultValue?: Value;
    rules?: Rules;
}
type FormSetup = {
    [key: string]: FormControlSetup;
};
interface FormControl {
    label: string;
    value: Value;
    dirty: boolean;
    rules: StrictRules;
    errors: string[];
    valid: boolean;
}
interface FormControlProps {
    onChange: (value: ChangeEvent<HTMLInputElement>) => void;
    onFocus: () => void;
    defaultValue?: string | number | undefined;
}
type FormControls = {
    [key: string]: FormControl;
};
interface FormInstance {
    props: {
        [key: string]: FormControlProps;
    };
    controls: FormControls;
    values: any;
    valid: () => boolean;
    markAsDirty: (controlName: string) => void;
    markAsClean: (controlName: string) => void;
    markAllAsDirty: () => void[];
    markAllAsClean: () => void[];
    setValue: (controlName: string, value: Value) => void;
    reset: () => void;
}
export declare function useMorf(setup: FormSetup): FormInstance;
export {};
